| Title: | Data preparation and generation of animated bubble charts (Gapminder style) using srvyr and gganimate. |
|---|---|
| Description: | Data preparation and generation of animated bubble charts (Gapminder style) using srvyr and gganimate. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.2 |
| Built: | 2026-06-24 20:38:37 UTC |
| Source: | https://github.com/AlfCano/rk.gganimate |